@@ -8,39 +8,50 @@
 import logging as _logging
 
 from ._exceptions import (
-    quiet_errors,
     ISBNLibException,
     NotRecognizedServiceError,
+    NotValidDefaultFormatterError,
+    NotValidDefaultServiceError,
     NotValidISBNError,
     PluginNotLoadedError,
-    NotValidDefaultServiceError,
-    NotValidDefaultFormatterError,
+    quiet_errors,
 )
 
 # main modules
 from ._core import (
-    is_isbn10,
-    is_isbn13,
-    to_isbn10,
-    to_isbn13,
+    canonical,
     check_digit10,
     check_digit13,
     clean,
-    canonical,
-    notisbn,
-    get_isbnlike,
-    get_canonical_isbn,
-    GTIN13,
     EAN13,
+    get_canonical_isbn,
+    get_isbnlike,
+    GTIN13,
+    is_isbn10,
+    is_isbn13,
+    notisbn,
     RE_ISBN10,
     RE_ISBN13,
     RE_LOOSE,
     RE_NORMAL,
     RE_STRICT,
+    to_isbn10,
+    to_isbn13,
 )
-from ._ext import cover, desc, mask, meta, info, editions, isbn_from_words, doi, ren
-from ._goom import query as goom
 from ._doitotex import doi2tex
+from ._ext import (
+    cover,
+    desc,
+    doi,
+    editions,
+    info,
+    isbn_from_words,
+    mask,
+    meta,
+    ren,
+)
+from ._goom import query as goom
+from ._isbn import Isbn
 from ._oclc import query_classify as classify
 
 # Ranges Database date
@@ -51,49 +62,50 @@ _nh = _logging.NullHandler()
 _logging.getLogger('isbnlib').addHandler(_nh)
 
 # alias
-ISBN13 = EAN13
 ean13 = EAN13
+ISBN13 = EAN13
 
 # dunders
 __all__ = (
-    'is_isbn10',
-    'is_isbn13',
-    'clean',
+    'canonical',
     'check_digit10',
     'check_digit13',
-    'mask',
-    'info',
-    'meta',
     'classify',
-    'to_isbn10',
-    'to_isbn13',
-    'get_isbnlike',
-    'notisbn',
-    'ean13',
-    'EAN13',
-    'ISBN13',
-    'GTIN13',
+    'clean',
     'cover',
     'desc',
-    'canonical',
-    'get_canonical_isbn',
-    'editions',
-    'isbn_from_words',
-    'goom',
     'doi',
     'doi2tex',
-    'ren',
-    'quiet_errors',
-    '__version__',
-    '__support__',
-    'RDDATE',
+    'ean13',
+    'EAN13',
+    'editions',
+    'get_canonical_isbn',
+    'get_isbnlike',
+    'goom',
+    'GTIN13',
+    'info',
+    'Isbn',
+    'ISBN13',
+    'isbn_from_words',
     'ISBNLibException',
+    'is_isbn10',
+    'is_isbn13',
+    'mask',
+    'meta',
+    'notisbn',
     'NotRecognizedServiceError',
-    'NotValidISBNError',
-    'PluginNotLoadedError',
     'NotValidDefaultFormatterError',
     'NotValidDefaultServiceError',
+    'NotValidISBNError',
+    'PluginNotLoadedError',
+    'quiet_errors',
+    'RDDATE',
+    'ren',
+    'to_isbn10',
+    'to_isbn13',
+    '__support__',
+    '__version__',
 )
 
-__version__ = '3.10.1'
+__version__ = '3.10.4'
 __support__ = 'py27, py35, py36, py37, py38, pypy, pypy3'
