@@ -2,7 +2,6 @@
 """Private helper functions."""
 
 import re
-import sys
 from hashlib import md5
 
 from ._bouth23 import b, s
@@ -10,7 +9,7 @@ from ._bouth23 import b, s
 
 def fake_isbn(title, author='unkown', publisher='unkown', sid=1):
     """Produce a fake ISBN from the (title, author, publisher) of the book."""
-    key = "%s %s %s" % (title, author, publisher)
+    key = '%s %s %s' % (title, author, publisher)
     # normalize
     regex1 = re.compile(r'\?|,|\.|!|\:|;', re.I | re.M | re.S)
     regex2 = re.compile(r'\s\s+', re.I | re.M | re.S)
@@ -20,12 +19,6 @@ def fake_isbn(title, author='unkown', publisher='unkown', sid=1):
     return (str(sid) + str(int(md5(b(key)).hexdigest()[:10], 16)))[:13]
 
 
-def in_virtual():  # pragma: no cover
-    """Detect if program is running inside a python virtual environment."""
-    return getattr(sys, 'base_prefix', sys.prefix) != sys.prefix or hasattr(
-        sys, 'real_prefix')
-
-
 def normalize_space(item):
     """Normalize white space.
 
@@ -37,14 +30,14 @@ def normalize_space(item):
 
 
 def titlecase(st):
-    """Format string in title case (for ascii).
-
-    Only changes the first character of each word.
-    """
+    """Format string in 'title case' (for ascii)."""
     try:
         st.encode('ascii')
-        return re.sub(r"[A-Za-z]+('[A-Za-z]+)?",
-                      lambda m: m.group(0)[0].upper() + m.group(0)[1:], st)
+        return re.sub(
+            r"[A-Za-z]+('[A-Za-z]+)?",
+            lambda m: m.group(0)[0].upper() + m.group(0)[1:],
+            st,
+        )
     except (UnicodeEncodeError, UnicodeDecodeError):  # pragma: no cover
         return st
 
@@ -65,9 +58,12 @@ def last_first(author):
 def unicode_to_utf8tex(utex, filtre=()):
     """Replace unicode entities with tex entitites and returns utf8 bytes."""
     from .._data.data4tex import unicode_to_tex
+
     btex = utex.encode('utf-8')
-    table = dict((k.encode('utf-8'), v) for k, v in unicode_to_tex.items()
-                 if v not in filtre)
+    table = {
+        k.encode('utf-8'): v
+        for k, v in unicode_to_tex.items() if v not in filtre
+    }
     regex = re.compile(b('|'.join(re.escape(s(k)) for k in table)))
     return regex.sub(lambda m: table[m.group(0)], btex)
 
@@ -77,9 +73,9 @@ def cutoff_tokens(tokens, cutoff):
     ltokens = [len(t) for t in tokens]
     length = 0
     stokens = []
-    for token, l in zip(tokens, ltokens):
-        if length + l <= cutoff:
-            length = length + l
+    for token, ln in zip(tokens, ltokens):
+        if length + ln <= cutoff:
+            length = length + ln
             stokens.append(token)
         else:
             break
