@@ -7,6 +7,7 @@ from pkg_resources import iter_entry_points
 
 from . import _goob as goob
 from . import _openl as openl
+from . import _wiki as wiki
 from . import NotValidDefaultServiceError
 from . import NotValidDefaultFormatterError
 from ._imcache import IMCache
@@ -21,6 +22,7 @@ services = {
     'default': goob.query,
     'goob': goob.query,
     'openl': openl.query,
+    'wiki': wiki.query,
 }
 
 PROVIDERS = ()
@@ -53,7 +55,8 @@ bibformatters = {
     'json': lambda x: _fmtbib('json', x),
     'opf': lambda x: _fmtbib('opf', x),
     'endnote': lambda x: _fmtbib('endnote', x),
-    'refworks': lambda x: _fmtbib('refworks', x),
+    'ris': lambda x: _fmtbib('ris', x),
+    'refworks': lambda x: _fmtbib('ris', x),
     'msword': lambda x: _fmtbib('msword', x),
 }  # pragma: no cover
 
